<template>
  <div v-if="productTypelx">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" :inline="true">
        <el-row :gutter="10">
          <el-col :span="6.5">
            <el-form-item label="入库时间">
              <el-date-picker
                v-model="querys[0].value"
                type="datetimerange"
                value-format="yyyy-MM-dd HH:mm:ss"
                range-separator="至"
                start-placeholder="开始日期"
                end-placeholder="结束日期"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-form-item>
              <el-button
                type="primary"
                icon="el-icon-search"
                @click="handleSearch"
              >搜索
              </el-button
              >
              <el-button
                icon="el-icon-refresh"
                @click="handleReset"
              >重置
              </el-button
              >
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <el-table
      border
      size="mini"
      :data="tableData"
      :height="tableMaxHeight - 150"
      :style="{width: '100%'}"
      :cell-style="{'text-align': 'center'}"
      :header-cell-style="{'text-align': 'center'}"
      @row-dblclick="handleDbClick"
      @selection-change="handleSelectionChange"
    >
      <el-table-column
        type="index"
        width="55"
        label="序号"
      ></el-table-column>
      <el-table-column
        sortable
        prop="deviceCode"
        label="设备标识"
        show-overflow-tooltip
      ></el-table-column>
      <el-table-column
        v-if="productTypelx == 'barricade'"
        sortable
        prop="createBy"
        label="操作人"
        show-overflow-tooltip
      ></el-table-column>
      <el-table-column
        sortable
        prop="collTime"
        :label="productTypelx == 'barricade' ? '操作时间' : '采集时间'"
        show-overflow-tooltip
      ></el-table-column>
      <el-table-column
        sortable
        prop="createTime"
        label="入库时间"
        show-overflow-tooltip
      ></el-table-column>
      <el-table-column
        v-if="productTypelx == 'barricade'"
        sortable
        prop="action"
        label="动作标识"
        show-overflow-tooltip
      ></el-table-column>
      <el-table-column
        v-if="productTypelx == 'barricade'"
        sortable
        prop="status"
        label="成功状态"
        show-overflow-tooltip
      ></el-table-column>
      <el-table-column
        v-if="productTypelx == 'signboaerd'"
        sortable
        prop="batteryValue"
        label="电池电量(单位：%)"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        v-if="productTypelx == 'signboaerd'"
        sortable
        prop="dataType"
        label="数据类型"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        v-if="productTypelx == 'signboaerd'"
        sortable
        prop="angleX"
        label="X轴角度（单位：°度）"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        v-if="productTypelx == 'signboaerd'"
        sortable
        prop="angleY"
        label="Y轴角度（单位：°度）"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        v-if="productTypelx == 'signboaerd'"
        sortable
        prop="angleZ"
        label="Z轴角度（单位：°度）"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        v-if="productTypelx == 'jwwxyjc'"
        sortable
        prop="sdata"
        label="气体浓度"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        v-if="productTypelx == 'dwjs'"
        sortable
        prop="sdata"
        label="水位高度（单位：cm）"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        v-if="productTypelx == 'bspqx'"
        prop="batteryVoltage"
        label="设备电压（单位：V）"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        v-if="productTypelx == 'jwwxyjc' || productTypelx == 'dwjs'"
        prop="voltage"
        label="设备电压（单位：V）"
        show-overflow-tooltip
      >
      </el-table-column>
    </el-table>
    <el-pagination
      align="right"
      background
      ref="paginationPanel"
      @size-change="handleSizeChange"
      @current-change="handleCurrentChange"
      :current-page="queryParam.pageBean.page"
      :page-sizes="[20, 30, 40, 50]"
      :page-size="queryParam.pageBean.pageSize"
      layout="total, sizes, prev, pager, next, jumper"
      :total="total"
    ></el-pagination>
  </div>
</template>

<script>
import req from '@/request.js'
import {TableMixin} from '@/mixins/tableMixin'
import equipmentManage from '@/api/device/equipmentManage.js'
import productManage from '@/api/device/productManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'RealTimeData',
  mixins: [TableMixin],
  props: {
    parameter: {
      type: Object,
      default: function() {
        return
      }
    }
  },
  data() {
    return {
      productParams: {},
      productType: {},
      realData: [],
      productTypelx: '',
      dataTypeList: [], //数据类型字典
      actionList: [], //动作标识字典
      statusList: [], //成功状态字典
      querys: [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'b.create_time_',
          relation: 'AND',
          value: ''
        }
      ]
    }
  },
  created() {
    console.log(this.parameter)
    this.dataTypeList = dictUtils.getDictItemsFromCache('sjlx')
    this.actionList = dictUtils.getDictItemsFromCache('dzbs')
    this.statusList = dictUtils.getDictItemsFromCache('cgzt')
    this.getProduct()
  },
  mounted() {
  },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
    },
    getProduct() {
      productManage
        .productInfoDetail(this.parameter.productId)
        .then((res) => {
          this.productParams = res
          productManage
            .productTypeDetail(this.productParams.typeId)
            .then((res) => {
              this.productType = res
              //   this.loadData()
            })
        })
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      let protal = window.context.portal
      let requestData = {
        url: `${protal}/device/data/query?id=` + this.parameter.id,
        data: this.queryParam,
        method: 'post'
      }
      // 根据设备id获取实时数据
      req.request(requestData)
        .then((res) => {
          console.log(res)
          if (res.status) {
            this.productTypelx = res.data.value.productType
            this.tableData = res.data.value.data.rows
            this.total = res.data.value.data.total
            this.$set(this.tableData)
            this.loading = false
            this.tableData.forEach((item) => {
              this.dataTypeList.forEach((val) => {
                if (
                  item.dataType &&
                  item.dataType == val.value
                ) {
                  item['dataType'] = val.name
                }
              })
              this.actionList.forEach((val) => {
                if (item.action && item.action == val.value) {
                  item['action'] = val.name
                }
              })
              this.statusList.forEach((val) => {
                if (item.status && item.status == val.value) {
                  item['status'] = val.name
                }
              })
            })
          }
        })
        .catch((err) => {
          console.log(err)
        })
    }
  }
}
</script>

<style lang="scss" scoped>
::v-deep .bbsl-table-search {
  height: 50px;
}
</style>
